==> mdm-rpc-0.0.31-sources.jar: com/chinayanghe/msp/mdm/vo/franchiser/PositionFranchiseCostRelationDetailVersionVo.java <==
package com.chinayanghe.msp.mdm.vo.franchiser;

import com.chinayanghe.msp.mdm.enums.ActivitiState;

import java.util.Date;
import java.util.List;

/**
 * @author bruce.qin
 * @usage
 * @reviewer
 * @since 2017/9/12
 */
public class PositionFranchiseCostRelationDetailVersionVo extends PositionFranchiseCostRelationVo{

    private static final long serialVersionUID = -5400607383809933930L;
    /**
     * 版本号
     */
    private String version;

    /**
     * 版本日期
     */
    private Date versionDate;

    /**
     * 分配经销商id
     */
    private List<String> franchiserIds;

    /**
     * 流程审批状态
     */
    private ActivitiState activitiState;

    /**
     * 流程审批状态描述
     */
    private String activitiStateDesc;

    public ActivitiState getActivitiState() {
        return activitiState;
    }

    public void setActivitiState(ActivitiState activitiState) {
        this.activitiState = activitiState;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public Date getVersionDate() {
        return versionDate;
    }

    public void setVersionDate(Date versionDate) {
        this.versionDate = versionDate;
    }

    public List<String> getFranchiserIds() {
        return franchiserIds;
    }

    public void setFranchiserIds(List<String> franchiserIds) {
        this.franchiserIds = franchiserIds;
    }

    public String getActivitiStateDesc() {
        return activitiState==null?null:activitiState.getDesc();
    }

    public void setActivitiStateDesc(String activitiStateDesc) {
        this.activitiStateDesc = activitiStateDesc;
    }
}

==> mdm-rpc-0.1.99-sources.jar: com/chinayanghe/msp/mdm/vo/franchiser/PositionFranchiseCostRelationDetailVersionVo.java <==
package com.chinayanghe.msp.mdm.vo.franchiser;

import com.chinayanghe.msp.mdm.enums.ActivitiState;

import java.util.Date;
import java.util.List;

/**
 * @author bruce.qin
 * @usage
 * @reviewer
 * @since 2017/9/12
 */
public class PositionFranchiseCostRelationDetailVersionVo extends PositionFranchiseCostRelationVo{

    private static final long serialVersionUID = -5400607383809933930L;
    /**
     * 版本号
     */
    private Long version;

    /**
     * 版本日期
     */
    private Date versionDate;

    /**
     * 分配经销商id
     */
    private List<String> franchiserIds;

    /**
     * 流程审批状态
     */
    private ActivitiState activitiState;

    /**
     * 流程审批状态描述
     */
    private String activitiStateDesc;

    public ActivitiState getActivitiState() {
        return activitiState;
    }

    public void setActivitiState(ActivitiState activitiState) {
        this.activitiState = activitiState;
    }

    public Long getVersion() {
        return version;
    }

    public void setVersion(Long version) {
        this.version = version;
    }

    public Date getVersionDate() {
        return versionDate;
    }

    public void setVersionDate(Date versionDate) {
        this.versionDate = versionDate;
    }

    public List<String> getFranchiserIds() {
        return franchiserIds;
    }

    public void setFranchiserIds(List<String> franchiserIds) {
        this.franchiserIds = franchiserIds;
    }

    public String getActivitiStateDesc() {
        return activitiState==null?null:activitiState.getDesc();
    }

    public void setActivitiStateDesc(String activitiStateDesc) {
        this.activitiStateDesc = activitiStateDesc;
    }
}
